@@ -1,6 +1,6 @@
 FA_METADATA = {
     "contacts": ["spid.tech@agid.gov.it"],
-    "federation_api_endpoint": "https://registry.spid.agid.gov.it/oidc/fedapi/",
+    "federation_fetch_endpoint": "https://registry.spid.agid.gov.it/oidc/fedapi/",
     "homepage_uri": "https://spid.agid.gov.it/",
     "name": "AgID",
 }
