@@ -39,3 +39,9 @@ RP_METADATA_CIE_JWKS_AND_JWKS_URI["jwks"] = JWKS
 
 RP_METADATA_CIE_NO_REDIRECT_URIS = deepcopy(RP_METADATA_CIE)
 RP_METADATA_CIE_NO_REDIRECT_URIS.pop("redirect_uris")
+
+RP_METADATA_SPID_NOJWKS_NOJWKS_URI = deepcopy(RP_METADATA_SPID)
+RP_METADATA_SPID_NOJWKS_NOJWKS_URI.pop("jwks_uri")
+
+RP_METADATA_CIE_NOJWKS_NOJWKS_URI = deepcopy(RP_METADATA_CIE)
+RP_METADATA_CIE_NOJWKS_NOJWKS_URI.pop("jwks_uri")
